import request from '@/utils/requestDoc.ts'
import { DOC_API, APP_BFF } from '@/api/baseApi'

/**
 * 按照类型显示文件列表
 * data: 类型（1文档 2pdf 3图片 4视频 5音频 99其他 0 全部）
 */
export function api_listFileType(data) {
  return request({
    method: 'post',
    url: DOC_API + '/api/pan/listFileType',
    data
  })
}

/**
 * 查看文件夹元素列表
 * data: 目录id，0为根目录
 */
export function api_listFolder(data) {
  return request({
    method: 'post',
    url: DOC_API + '/api/pan/listFolder',
    data
  })
}

/**
 * 查找文件
 * data: keywords
 */
export function api_searchFile(data) {
  return request({
    method: 'post',
    url: DOC_API + '/api/pan/searchFile',
    data
  })
}

/**
 * 文件详情
 */
export function api_fileDetail(data) {
  return request({
    method: 'post',
    url: DOC_API + '/api/pan/fileDetail',
    data
  })
}

/**
 * 保存文件引用
 */
export function api_saveFileRef(data) {
  return request({
    method: 'post',
    url: DOC_API + '/api/pan/upload/saveFileRef',
    data
  })
}

/**
 * 文档权限申请
 */
export function api_IsAgreeJoinDoc(data) {
  return request({
    method: 'post',
    url: DOC_API + '/api/pan/upload/saveFileRef',
    data
  })
}

/** 为获取文档信息 */
export function api_doc_getInfo(doc_id: string) {
  const type = doc_id.split('_')[0]
  switch (type) {
    case 'doc':
      return request({
        method: 'post',
        url: DOC_API + '/api/tool/view/doc/info',
        data: { doc_view_id: doc_id }
      })
    case 'excel':
      return request({
        method: 'post',
        url: DOC_API + '/api/tool/view/excel/base/info',
        data: { excel_view_id: doc_id }
      })
    default:
      return Promise.reject('未支持的文档类型')
  }
}

/**
 * 发送消息
 */
export function api_sendBothMessage(data: any) {
  return request({
    method: 'post',
    url: DOC_API + '/api/im/sendBothMessage',
    data
  })
}

/**
 * 获取文档列表
 */
export function api_getDocList(data: any) {
  return request({
    method: 'post',
    url: DOC_API + '/api/tool/view/home/list',
    data
  })
}

/**
 * 创建文档
 */
export function api_createWord(data: any) {
  return request({
    method: 'post',
    url: DOC_API + '/api/tool/operator/doc/create',
    data
  })
}

/**
 * 创建表格
 */
export function api_createExcel(data: any) {
  return request({
    method: 'post',
    url: DOC_API + '/api/tool/operator/excel/create',
    data
  })
}

// 获取用户基本信息
export function api_userinfo(data: any) {
  return request({
    method: 'post',
    url: DOC_API + '/api/passport/usercenter/user/info',
    data
  })
}
