import { postRequest } from '@/utils/requestLink';
import { LINK_API } from '@/api/baseApi';
import * as T from './types';

/* 用户信息 */
export function api_getUserInfo() {
  return postRequest({
    url: LINK_API + '/User/getUserInfo',
    config: { noMsg: true },
  });
}

/* 行业列表 */
export function api_getIndustryList() {
  return postRequest({
    url: LINK_API + '/Articles/getIndustryList',
  });
}

/* 更新im信息 */
export function api_updateGuide(data: any) {
  return postRequest({
    url: LINK_API + '/User/updateGuide',
    data,
    config: { noMsg: true },
  });
}

/*
 * describe: 更换用户绑定手机号
 * data: 参数字段限制说明 T.PhoneParams
 * */
export function api_modifyPhone(data: T.PhoneParams) {
  return postRequest({
    url: LINK_API + '/User/modifyPhone',
    data,
  });
}

/**
 * @description: 搜索全部注册用户
 * @param {any} data
 * @return {*}
 */
export function api_searchWyPc(data: any) {
  return postRequest({
    url: LINK_API + '/common/searchWyPc',
    data,
  });
}
/*
 * describe: 角色信息
 * */
export function api_getRoleList() {
  return postRequest({
    url: LINK_API + '/Common/roleList',
  });
}

/*
 * describe: 认证信息
 * */
export function api_applyClubUserRecord() {
  return postRequest({
    url: LINK_API + '/SmallMine/applyClubUserRecord',
  });
}
/*
 * describe: 发起认证
 * */
export function api_applyClubUser(data: T.AuthParams) {
  return postRequest({
    url: LINK_API + '/User/applyClubUser',
    data,
  });
}
/*
 * describe: 发起认证-学生
 * */
export function api_studentAuth(data: T.StudentParams) {
  return postRequest({
    url: LINK_API + '/User/studentAuth',
    data,
  });
}

/*
 * describe: 获取个人主页详情信息
 * */
export function api_personDetail(data: any) {
  return postRequest({
    url: LINK_API + '/SmallPerson/personDetail',
    data,
  });
}

/*
 * describe: 加为人脉
 * */
export function api_addUserToContactGroup(data: any) {
  return postRequest({
    url: LINK_API + '/user/addUserToContactGroup',
    data,
  });
}

/*
 * describe: 通过im——id获取用户信息
 * */
export function api_getUserInfoByIm(data: any) {
  return postRequest({
    url: LINK_API + '/user/getUserInfoByIm',
    data,
  });
}

/*
 * describe: 获取企业主页详情信息
 * */
export function api_companyBasicInfo(data: any) {
  return postRequest({
    url: LINK_API + '/SmallCompany/companyBasicInfo',
    data,
  });
}

/*
 * describe: 获取企业token 有token值代表有企业，空代表无企业需引导
 * */
export function api_getBusinessTokenBySee() {
  return postRequest({
    url: LINK_API + '/SmallCompany/getBusinessTokenBySee',
  });
}

/*
 * describe: 获取服务窗详情 has_account 1/0 是否开通
 * */
export function api_getBusinessInfoBySee() {
  return postRequest({
    url: LINK_API + '/SmallCompany/getBusinessInfoBySee',
  });
}

/*
 * describe: 搜索企业联系人
 * */
export function api_searchItemWyPc(data: any) {
  return postRequest({
    url: LINK_API + '/common/searchItemWyPc',
    data,
  });
}

/*
 * describe: 获取企业库推荐
 * */
export function api_recommendedItemList(data: any) {
  return postRequest({
    url: LINK_API + '/SmallHomePage/recommendedItemList',
    data,
  });
}

/*
 * describe: 搜索用户联系人
 * */
export function api_searchUserWyPc(data: any) {
  return postRequest({
    url: LINK_API + '/common/searchUserWyPc',
    data,
  });
}

/*
 * describe: 人脉推荐
 * */
export function api_recommendUserList(data: any) {
  return postRequest({
    url: LINK_API + '/SmallClub/recommendUserList',
    data,
  });
}

/*
 * describe: 我的人脉列表
 * */
export function api_contactListGroup() {
  return postRequest({
    url: LINK_API + '/user/contactListGroup',
  });
}

/*
 * describe: 联系我的人列表
 * */
export function api_contactMeList(data: any) {
  return postRequest({
    url: LINK_API + '/user/contactMeList',
    data,
  });
}

/*
 * describe: 名片夹列表
 * */
export function api_receiveContactCard(data: any) {
  return postRequest({
    url: LINK_API + '/user/receiveContactCard',
    data,
  });
}

/*
 * describe: 发送名片
 * */
export function api_sendContactCard(data: any) {
  return postRequest({
    url: LINK_API + '/user/sendContactCard',
    data,
  });
}

/*
 * describe: 添加联系人分组
 * */
export function api_createContactGroup(data: any) {
  return postRequest({
    url: LINK_API + '/user/createContactGroup',
    data,
  });
}

/*
 * describe: 删除联系人分组
 * */
export function api_delContactGroup(data: any) {
  return postRequest({
    url: LINK_API + '/user/delContactGroup',
    data,
  });
}

/*
 * describe: 编辑联系人分组
 * */
export function api_editContactGroup(data: any) {
  return postRequest({
    url: LINK_API + '/user/editContactGroup',
    data,
  });
}

/*
 * describe: 移除人脉
 * */
export function api_deleteContact(data: any) {
  return postRequest({
    url: LINK_API + '/user/deleteContact',
    data,
  });
}

/*
 * describe: 搜索用户接口
 * */
export function api_searchContact(data: any) {
  return postRequest({
    url: LINK_API + '/user/searchContact',
    data,
  });
}
/*
 * describe: 退出群聊
 * */
export function api_exitChannel(data: any) {
  return postRequest({
    url: LINK_API + '/im/exitChannel',
    data,
  });
}

/*
 * describe: 获取省市
 * */
export function api_provinceCityList() {
  return postRequest({
    url: LINK_API + '/common/provinceCityList',
  });
}

/*
 * describe: 获取新闻列表
 * */
export function api_mpNewsList(data: any) {
  return postRequest({
    url: LINK_API + '/News/mpNewsList',
    data,
  });
}

/*
 * describe: 推荐品牌号列表
 * */
export function api_recommendationCa(data: any) {
  return postRequest({
    url: LINK_API + '/im/recommendationCa',
    data,
  });
}

/**
 * @description: 获取当前用户的服务窗列表
 * @param {any} data
 * @return {*}
 */
export function api_showUserBusinessTeam(data: any) {
  return postRequest({
    url: LINK_API + '/common/showUserBusinessTeam',
    data,
  });
}

export function api_getMpUuidBySee() {
  return postRequest({
    url: LINK_API + '/SmallCompany/getMpUuidBySee',
    config: { noMsg: true },
  });
}
