import { ref } from 'vue'
import { api_corpusList, api_corpusAdd, api_corpusUpdate, api_corpusDelete } from '@/api/corpus'
import { ElMessage } from 'element-plus'

const useHandleList = () => {
  const corpusList = ref([])
  const loading = ref(false)
  const getCorpusList = async () => {
    loading.value = true
    let res = await api_corpusList({})
    loading.value = false
    const { list } = res.data
    corpusList.value = list
  }
  const handleSave = async (content) => {
    let res = await api_corpusAdd({ content })
    if (res.status === 0) {
      ElMessage.success('保存成功')
      getCorpusList()
    } else {
      ElMessage.error(res.message)
    }
  }

  const handleEditSave = async (id, content) => {
    let res = await api_corpusUpdate({ record_id: id, content })
    if (res.status === 0) {
      ElMessage.success('修改成功')
      const index = corpusList.value.findIndex((item) => item.id == id)
      corpusList.value[index].content = content
    } else {
      ElMessage.error(res.message)
    }
  }
  const handleDeleteConfirm = async (id) => {
    let res = await api_corpusDelete({ record_id: id })
    if (res.status === 0) {
      ElMessage.success('删除成功')
      const index = corpusList.value.findIndex((item) => item.id == id)
      corpusList.value.splice(index, 1)
    } else {
      ElMessage.error(res.message)
    }
  }
  return {
    getCorpusList,
    handleSave,
    handleDeleteConfirm,
    handleEditSave,
    corpusList,
    loading
  }
}
export default useHandleList
