import Quill from 'quill'
import Delta from 'quill-delta'
import { api_doc_getInfo } from '@/api/doc-api'

const Inline = Quill.import('blots/inline')

const urlToDoc = async (node, value) => {
  const obj = new URL(value)
  // 判断是否是文档url
  if (['docsdev.qmpsee.com', 'docs.qmpsee.com'].includes(obj.host)) {
    const arr = obj.pathname.split('/')
    const doc_id = arr[arr.length - 1]
    if (!doc_id) {
      return
    }
    const { data } = await api_doc_getInfo(doc_id)
    setTimeout(() => {
      const blot = node.__blot?.blot
      const quill = blot && blot.domNode.closest('.im-editor').__quill
      if (blot && quill) {
        const index = quill.getIndex(blot)
        const length = blot.length()
        // 删除原有a标签
        const ops = new Delta().retain(index).delete(length)
        quill.updateContents(ops)
        const { name } = data
        // 添加DocBlot
        const ops2 = new Delta().retain(index).insert({ DocBlot: { name, url: value } })
        quill.updateContents(ops2)
        quill.setSelection(index + 1, Quill.sources.USER)
      }
    })
  }
}
class LinkIM extends Inline {
  static create(value) {
    const node = super.create(value)
    node.setAttribute('href', this.sanitize(value))
    node.setAttribute('target', 'new-tab')
    node.addEventListener('click', (e) => {
      if (!e.target.className.includes('im-doc-link')) {
        e.stopPropagation()
        e.preventDefault()
      }
    })
    urlToDoc(node, value)
    return node
  }

  static formats(domNode) {
    return domNode.getAttribute('href')
  }

  static sanitize(url) {
    return sanitize(url, this.PROTOCOL_WHITELIST) ? url : this.SANITIZED_URL
  }

  format(name, value) {
    if (name !== this.statics.blotName || !value) {
      super.format(name, value)
    } else {
      this.domNode.setAttribute('href', this.constructor.sanitize(value))
    }
  }
}
LinkIM.blotName = 'LinkIM'
LinkIM.tagName = 'A'
LinkIM.SANITIZED_URL = 'about:blank'
LinkIM.PROTOCOL_WHITELIST = ['http', 'https', 'mailto', 'tel']

function sanitize(url, protocols) {
  const anchor = document.createElement('a')
  anchor.href = url
  const protocol = anchor.href.slice(0, anchor.href.indexOf(':'))
  return protocols.indexOf(protocol) > -1
}

export default LinkIM
