import { useUserImStore } from '@/store/userIm';
import { socketSendFn } from './useWebSocket';
import { deleteTempMessageFromDB } from '@/components/chat-module/db/tempMessage';
import { tipMessage } from '@/components/chat-module/msgUtils/msgFormat';
import {
  addMessageToDB,
  updateMessageToDB,
  updateMessageReadState,
} from '@/components/chat-module/db/message';
import { nextTick } from 'vue';
let imStore = null;
const noReadMsgType = ['notify', 'exit_channel', 'join_channel', 'tip'];
const updateMsgType = ['notify'];
// 消息处理
export const messageHandle = (body, connectType, im_id) => {
  imStore = imStore || useUserImStore();
  if (body.id) {
    // ack
    socketSendFn({ cmd: 'ack', body: { id: body.id } }, connectType, body.uniq_id);
    deleteTempMessageFromDB(body.custom_id);
  }
  if (!noReadMsgType.includes(body.msg_type) && body.uniq_id !== im_id && body?.is_show === 1) {
    if (imStore.cur_room_id !== body.room_id) {
      // resend:1 标识重发
      if (body.open_tip === 1 && !body.resend) {
        const isGroup = body.room_type === 1 || body.room_type === 3;
        let type = 'all';
        let title = isGroup ? body.room_name : body.name;
        if (body.room_type === 3) {
          type = 'group';
        } else if (body.room_type === 1) {
          type = 'square';
        } else if (imStore.navIdList.includes(body.to_user?.uniq_id)) {
          type = body.to_user?.uniq_id.startsWith('content_') ? 'content' : 'enterprise';
        }

        if (type === 'enterprise' || type === 'content') {
          title =
            `${type === 'enterprise' ? '服务窗' : '品牌号'}[` +
            (body.to_user.name || '') +
            ']-' +
            body.name;
          enterpriseUnreadHandle(body);
        } else if (imStore.chatType === 'findPeople') {
          // 不在UserChat路由下，计算count
          userUnreadHandle(body);
        }

        const content = tipMessage(body, imStore.im_id, body.room_type, imStore.user_uuid);
        const routeName =
          type === 'enterprise' ? 'Enterprise' : type === 'content' ? 'IMContent' : 'UserChat';
        window.electronIPC.notify({
          title,
          body: content,
          room_id: body.room_id,
          type,
          enterprise_id: type === 'enterprise' || type === 'content' ? body.to_user?.uniq_id : '',
          routeName,
        });
        // window.electronIPC.onNotifyClick((e, params) => {
        //   console.log('通知被点击', params)
        // })
      }
    }
  }
  // 更新db消息
  const {
    attached,
    company = '',
    create_time,
    custom_id,
    icon,
    id,
    is_mention,
    is_read = 0,
    is_show,
    msg,
    msg_type,
    name,
    position = '',
    room_id,
    room_type,
    type,
    uniq_id,
  } = body;
  const message = {
    attached,
    company,
    create_time,
    custom_id,
    icon,
    id,
    is_mention,
    is_read,
    is_show,
    msg,
    msg_type,
    name,
    position,
    room_id: Number(room_id),
    room_type,
    type,
    uniq_id,
  };
  if (body.msg_type === 'notify' && message.uniq_id !== im_id) {
    // 更新已读状态
    updateMessageReadState(message.room_id);
  } else if (message?.is_show === 0) {
    // 撤回
    updateMessageToDB(message.room_id, message);
  } else if (body.msg_type !== 'notify') {
    // 新消息
    addMessageToDB(message.room_id, message);
  }
};
// 计算服务窗未读数
const enterpriseUnreadHandle = body => {
  const to_user_id = body.to_user.uniq_id;
  if (imStore.navIdList.includes(to_user_id)) {
    if (imStore.business_unread_map[to_user_id]) {
      imStore.business_unread_map[to_user_id]++;
    } else {
      imStore.business_unread_map[to_user_id] = body.unread_total || 1;
    }
  }
};
// 计算用户未读数
const userUnreadHandle = item => {
  const numMap = {
    all: 0,
    single: 0,
    group: 0,
    robot: 0,
    business: 0,
    content: 0,
    square: 0,
  };
  if (item.room_type === 0) {
    numMap.all += 1; // 全部
  }
  if (item.type === 'business') {
    numMap.business += 1; // 服务窗
  } else if (item.room_type === 1) {
    numMap.square += 1; // 群聊广场
  } else if (item.type === 'tool' || item.type === 'content' || item.type === 'detail') {
    numMap.robot += 1; // 助手
  } else if (item.room_type === 0) {
    numMap.single += 1; // 单聊
  } else if (item.room_type > 1) {
    numMap.group += 1; // 好友群聊
  }
  imStore.navList.map(menu => {
    if (numMap[menu.key]) {
      menu.unread += numMap[menu.key];
    }
  });
  nextTick(() => {
    window.electronIPC?.changeNewMsgCount(imStore.total || 0);
  });
};
