import { defineConfig, loadEnv } from 'vite';
import vue from '@vitejs/plugin-vue';
import AutoImport from 'unplugin-auto-import/vite';
import Components from 'unplugin-vue-components/vite';
import ElementPlus from 'unplugin-element-plus/vite';
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers';
import { createHtmlPlugin } from 'vite-plugin-html';
import { resolve } from 'path';
import WindiCSS from 'vite-plugin-windicss';

function manualChunks(id) {
  if (
    id.includes('node_modules/vue') ||
    id.includes('node_modules/vue-router') ||
    id.includes('node_modules/vue-cropper') ||
    id.includes('node_modules/vuedraggable') ||
    id.includes('node_modules/axios') ||
    id.includes('node_modules/pinia') ||
    id.includes('node_modules/pinia-plugin-persistedstate') ||
    id.includes('node_modules/dayjs') ||
    id.includes('node_modules/snabbdom') ||
    id.includes('assets/iconfont')
  ) {
    return 'base';
  }
}

export default defineConfig({
  resolve: {
    alias: {
      '@': resolve(__dirname, './src'),
    },
  },
  css: {
    preprocessorOptions: {
      scss: {
        sourceMap: true,
        // additionalData: [`@import "./src/render/styles/mixin.scss";`],
        additionalData(source, fp) {
          // All scss files ending with imports.scss
          // will not re-import additionalData
          if (fp.endsWith('variables.scss') || fp.includes('node_modules')) {
            return source;
          }
          // Use additionalData from legacy nuxt scss options
          return `@import "./src/styles/variables.scss"; ${source}`;
        },
      },
    },
  },
  define: {
    'process.env.NODE_ENV': '"production"',
  },
  plugins: [
    vue(),
    WindiCSS(),
    createHtmlPlugin({
      inject: {
        ejsOptions: {},
      },
    }),
    AutoImport({
      resolvers: [
        ElementPlusResolver({
          importStyle: 'sass',
        }),
      ],
    }),
    Components({
      resolvers: [
        ElementPlusResolver({
          importStyle: 'sass',
        }),
      ],
    }),
    ElementPlus({
      useSource: true,
    }),
  ],
  build: {
    target: 'ESNext',
    lib: {
      entry: resolve(__dirname, './export.js'),
      name: 'qmp-im',
      fileName: 'index',
    },
    outDir: 'dist',
    rollupOptions: {
      external: ['vue', 'axios', 'element-plus', '@element-plus/icons-vue'],
    },
    cssCodeSplit: true,
  },
});
